==> blueocean-pipeline-editor-1.5.0-sources.jar: jenkins/plugins/blueocean/pipeline/editor/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.plugins.blueocean.pipeline.editor;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code editor.jenkins.environment.value}: {@code Value}.
     * 
     * @return
     *     {@code Value}
     */
    public static String editor_jenkins_environment_value() {
        return holder.format("editor.jenkins.environment.value");
    }

    /**
     * Key {@code editor.jenkins.environment.value}: {@code Value}.
     * 
     * @return
     *     {@code Value}
     */
    public static Localizable _editor_jenkins_environment_value() {
        return new Localizable(holder, "editor.jenkins.environment.value");
    }

    /**
     * Key {@code editor.page.common.pipeline.setting}: {@code Pipeline
     * Settings}.
     * 
     * @return
     *     {@code Pipeline Settings}
     */
    public static String editor_page_common_pipeline_setting() {
        return holder.format("editor.page.common.pipeline.setting");
    }

    /**
     * Key {@code editor.page.common.pipeline.setting}: {@code Pipeline
     * Settings}.
     * 
     * @return
     *     {@code Pipeline Settings}
     */
    public static Localizable _editor_page_common_pipeline_setting() {
        return new Localizable(holder, "editor.page.common.pipeline.setting");
    }

    /**
     * Key {@code editor.page.common.remove}: {@code Remove}.
     * 
     * @return
     *     {@code Remove}
     */
    public static String editor_page_common_remove() {
        return holder.format("editor.page.common.remove");
    }

    /**
     * Key {@code editor.page.common.remove}: {@code Remove}.
     * 
     * @return
     *     {@code Remove}
     */
    public static Localizable _editor_page_common_remove() {
        return new Localizable(holder, "editor.page.common.remove");
    }

    /**
     * Key {@code editor.jenkins.pipeline.step.substep}: {@code Child steps}.
     * 
     * @return
     *     {@code Child steps}
     */
    public static String editor_jenkins_pipeline_step_substep() {
        return holder.format("editor.jenkins.pipeline.step.substep");
    }

    /**
     * Key {@code editor.jenkins.pipeline.step.substep}: {@code Child steps}.
     * 
     * @return
     *     {@code Child steps}
     */
    public static Localizable _editor_jenkins_pipeline_step_substep() {
        return new Localizable(holder, "editor.jenkins.pipeline.step.substep");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.choose}: {@code Choose
     * step type}.
     * 
     * @return
     *     {@code Choose step type}
     */
    public static String editor_page_common_pipeline_steps_choose() {
        return holder.format("editor.page.common.pipeline.steps.choose");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.choose}: {@code Choose
     * step type}.
     * 
     * @return
     *     {@code Choose step type}
     */
    public static Localizable _editor_page_common_pipeline_steps_choose() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.choose");
    }

    /**
     * Key {@code editor.jenkins.environment.name}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static String editor_jenkins_environment_name() {
        return holder.format("editor.jenkins.environment.name");
    }

    /**
     * Key {@code editor.jenkins.environment.name}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static Localizable _editor_jenkins_environment_name() {
        return new Localizable(holder, "editor.jenkins.environment.name");
    }

    /**
     * Key {@code editor.jenkins.agent}: {@code Agent}.
     * 
     * @return
     *     {@code Agent}
     */
    public static String editor_jenkins_agent() {
        return holder.format("editor.jenkins.agent");
    }

    /**
     * Key {@code editor.jenkins.agent}: {@code Agent}.
     * 
     * @return
     *     {@code Agent}
     */
    public static Localizable _editor_jenkins_agent() {
        return new Localizable(holder, "editor.jenkins.agent");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps}: {@code Steps}.
     * 
     * @return
     *     {@code Steps}
     */
    public static String editor_page_common_pipeline_steps() {
        return holder.format("editor.page.common.pipeline.steps");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps}: {@code Steps}.
     * 
     * @return
     *     {@code Steps}
     */
    public static Localizable _editor_page_common_pipeline_steps() {
        return new Localizable(holder, "editor.page.common.pipeline.steps");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.add}: {@code Add step}.
     * 
     * @return
     *     {@code Add step}
     */
    public static String editor_page_common_pipeline_steps_add() {
        return holder.format("editor.page.common.pipeline.steps.add");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.add}: {@code Add step}.
     * 
     * @return
     *     {@code Add step}
     */
    public static Localizable _editor_page_common_pipeline_steps_add() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.add");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.required}: {@code There
     * are no steps, at least one is required.}.
     * 
     * @return
     *     {@code There are no steps, at least one is required.}
     */
    public static String editor_page_common_pipeline_steps_required() {
        return holder.format("editor.page.common.pipeline.steps.required");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.required}: {@code There
     * are no steps, at least one is required.}.
     * 
     * @return
     *     {@code There are no steps, at least one is required.}
     */
    public static Localizable _editor_page_common_pipeline_steps_required() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.required");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.child.require}: {@code
     * There are no child steps defined}.
     * 
     * @return
     *     {@code There are no child steps defined}
     */
    public static String editor_page_common_pipeline_steps_child_require() {
        return holder.format("editor.page.common.pipeline.steps.child.require");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.child.require}: {@code
     * There are no child steps defined}.
     * 
     * @return
     *     {@code There are no child steps defined}
     */
    public static Localizable _editor_page_common_pipeline_steps_child_require() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.child.require");
    }

    /**
     * Key {@code editor.page.common.add}: {@code Add}.
     * 
     * @return
     *     {@code Add}
     */
    public static String editor_page_common_add() {
        return holder.format("editor.page.common.add");
    }

    /**
     * Key {@code editor.page.common.add}: {@code Add}.
     * 
     * @return
     *     {@code Add}
     */
    public static Localizable _editor_page_common_add() {
        return new Localizable(holder, "editor.page.common.add");
    }

    /**
     * Key {@code editor.page.common.setting}: {@code Settings}.
     * 
     * @return
     *     {@code Settings}
     */
    public static String editor_page_common_setting() {
        return holder.format("editor.page.common.setting");
    }

    /**
     * Key {@code editor.page.common.setting}: {@code Settings}.
     * 
     * @return
     *     {@code Settings}
     */
    public static Localizable _editor_page_common_setting() {
        return new Localizable(holder, "editor.page.common.setting");
    }

    /**
     * Key {@code editor.page.common.cancel}: {@code Cancel}.
     * 
     * @return
     *     {@code Cancel}
     */
    public static String editor_page_common_cancel() {
        return holder.format("editor.page.common.cancel");
    }

    /**
     * Key {@code editor.page.common.cancel}: {@code Cancel}.
     * 
     * @return
     *     {@code Cancel}
     */
    public static Localizable _editor_page_common_cancel() {
        return new Localizable(holder, "editor.page.common.cancel");
    }

    /**
     * Key {@code branchdetail.actionbutton.pipeline.edit}: {@code Edit}.
     * 
     * @return
     *     {@code Edit}
     */
    public static String branchdetail_actionbutton_pipeline_edit() {
        return holder.format("branchdetail.actionbutton.pipeline.edit");
    }

    /**
     * Key {@code branchdetail.actionbutton.pipeline.edit}: {@code Edit}.
     * 
     * @return
     *     {@code Edit}
     */
    public static Localizable _branchdetail_actionbutton_pipeline_edit() {
        return new Localizable(holder, "branchdetail.actionbutton.pipeline.edit");
    }

    /**
     * Key {@code editor.page.common.save}: {@code Save}.
     * 
     * @return
     *     {@code Save}
     */
    public static String editor_page_common_save() {
        return holder.format("editor.page.common.save");
    }

    /**
     * Key {@code editor.page.common.save}: {@code Save}.
     * 
     * @return
     *     {@code Save}
     */
    public static Localizable _editor_page_common_save() {
        return new Localizable(holder, "editor.page.common.save");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.findby.name}: {@code Find
     * steps by name}.
     * 
     * @return
     *     {@code Find steps by name}
     */
    public static String editor_page_common_pipeline_steps_findby_name() {
        return holder.format("editor.page.common.pipeline.steps.findby.name");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.findby.name}: {@code Find
     * steps by name}.
     * 
     * @return
     *     {@code Find steps by name}
     */
    public static Localizable _editor_page_common_pipeline_steps_findby_name() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.findby.name");
    }

    /**
     * Key {@code editor.page.common.delete}: {@code Delete}.
     * 
     * @return
     *     {@code Delete}
     */
    public static String editor_page_common_delete() {
        return holder.format("editor.page.common.delete");
    }

    /**
     * Key {@code editor.page.common.delete}: {@code Delete}.
     * 
     * @return
     *     {@code Delete}
     */
    public static Localizable _editor_page_common_delete() {
        return new Localizable(holder, "editor.page.common.delete");
    }

    /**
     * Key {@code editor.page.common.pipeline.stages.input}: {@code Name your
     * stage}.
     * 
     * @return
     *     {@code Name your stage}
     */
    public static String editor_page_common_pipeline_stages_input() {
        return holder.format("editor.page.common.pipeline.stages.input");
    }

    /**
     * Key {@code editor.page.common.pipeline.stages.input}: {@code Name your
     * stage}.
     * 
     * @return
     *     {@code Name your stage}
     */
    public static Localizable _editor_page_common_pipeline_stages_input() {
        return new Localizable(holder, "editor.page.common.pipeline.stages.input");
    }

    /**
     * Key {@code editor.jenkins.environment}: {@code Environment}.
     * 
     * @return
     *     {@code Environment}
     */
    public static String editor_jenkins_environment() {
        return holder.format("editor.jenkins.environment");
    }

    /**
     * Key {@code editor.jenkins.environment}: {@code Environment}.
     * 
     * @return
     *     {@code Environment}
     */
    public static Localizable _editor_jenkins_environment() {
        return new Localizable(holder, "editor.jenkins.environment");
    }

}

==> blueocean-pipeline-editor-1.15.0-sources.jar: jenkins/plugins/blueocean/pipeline/editor/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.plugins.blueocean.pipeline.editor;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code editor.jenkins.environment.value}: {@code Value}.
     * 
     * @return
     *     {@code Value}
     */
    public static String editor_jenkins_environment_value() {
        return holder.format("editor.jenkins.environment.value");
    }

    /**
     * Key {@code editor.jenkins.environment.value}: {@code Value}.
     * 
     * @return
     *     {@code Value}
     */
    public static Localizable _editor_jenkins_environment_value() {
        return new Localizable(holder, "editor.jenkins.environment.value");
    }

    /**
     * Key {@code editor.page.common.pipeline.setting}: {@code Pipeline
     * Settings}.
     * 
     * @return
     *     {@code Pipeline Settings}
     */
    public static String editor_page_common_pipeline_setting() {
        return holder.format("editor.page.common.pipeline.setting");
    }

    /**
     * Key {@code editor.page.common.pipeline.setting}: {@code Pipeline
     * Settings}.
     * 
     * @return
     *     {@code Pipeline Settings}
     */
    public static Localizable _editor_page_common_pipeline_setting() {
        return new Localizable(holder, "editor.page.common.pipeline.setting");
    }

    /**
     * Key {@code editor.page.common.remove}: {@code Remove}.
     * 
     * @return
     *     {@code Remove}
     */
    public static String editor_page_common_remove() {
        return holder.format("editor.page.common.remove");
    }

    /**
     * Key {@code editor.page.common.remove}: {@code Remove}.
     * 
     * @return
     *     {@code Remove}
     */
    public static Localizable _editor_page_common_remove() {
        return new Localizable(holder, "editor.page.common.remove");
    }

    /**
     * Key {@code editor.jenkins.pipeline.step.substep}: {@code Child steps}.
     * 
     * @return
     *     {@code Child steps}
     */
    public static String editor_jenkins_pipeline_step_substep() {
        return holder.format("editor.jenkins.pipeline.step.substep");
    }

    /**
     * Key {@code editor.jenkins.pipeline.step.substep}: {@code Child steps}.
     * 
     * @return
     *     {@code Child steps}
     */
    public static Localizable _editor_jenkins_pipeline_step_substep() {
        return new Localizable(holder, "editor.jenkins.pipeline.step.substep");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.choose}: {@code Choose
     * step type}.
     * 
     * @return
     *     {@code Choose step type}
     */
    public static String editor_page_common_pipeline_steps_choose() {
        return holder.format("editor.page.common.pipeline.steps.choose");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.choose}: {@code Choose
     * step type}.
     * 
     * @return
     *     {@code Choose step type}
     */
    public static Localizable _editor_page_common_pipeline_steps_choose() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.choose");
    }

    /**
     * Key {@code editor.jenkins.environment.name}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static String editor_jenkins_environment_name() {
        return holder.format("editor.jenkins.environment.name");
    }

    /**
     * Key {@code editor.jenkins.environment.name}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static Localizable _editor_jenkins_environment_name() {
        return new Localizable(holder, "editor.jenkins.environment.name");
    }

    /**
     * Key {@code editor.jenkins.agent}: {@code Agent}.
     * 
     * @return
     *     {@code Agent}
     */
    public static String editor_jenkins_agent() {
        return holder.format("editor.jenkins.agent");
    }

    /**
     * Key {@code editor.jenkins.agent}: {@code Agent}.
     * 
     * @return
     *     {@code Agent}
     */
    public static Localizable _editor_jenkins_agent() {
        return new Localizable(holder, "editor.jenkins.agent");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps}: {@code Steps}.
     * 
     * @return
     *     {@code Steps}
     */
    public static String editor_page_common_pipeline_steps() {
        return holder.format("editor.page.common.pipeline.steps");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps}: {@code Steps}.
     * 
     * @return
     *     {@code Steps}
     */
    public static Localizable _editor_page_common_pipeline_steps() {
        return new Localizable(holder, "editor.page.common.pipeline.steps");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.add}: {@code Add step}.
     * 
     * @return
     *     {@code Add step}
     */
    public static String editor_page_common_pipeline_steps_add() {
        return holder.format("editor.page.common.pipeline.steps.add");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.add}: {@code Add step}.
     * 
     * @return
     *     {@code Add step}
     */
    public static Localizable _editor_page_common_pipeline_steps_add() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.add");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.required}: {@code There
     * are no steps, at least one is required.}.
     * 
     * @return
     *     {@code There are no steps, at least one is required.}
     */
    public static String editor_page_common_pipeline_steps_required() {
        return holder.format("editor.page.common.pipeline.steps.required");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.required}: {@code There
     * are no steps, at least one is required.}.
     * 
     * @return
     *     {@code There are no steps, at least one is required.}
     */
    public static Localizable _editor_page_common_pipeline_steps_required() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.required");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.child.require}: {@code
     * There are no child steps defined}.
     * 
     * @return
     *     {@code There are no child steps defined}
     */
    public static String editor_page_common_pipeline_steps_child_require() {
        return holder.format("editor.page.common.pipeline.steps.child.require");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.child.require}: {@code
     * There are no child steps defined}.
     * 
     * @return
     *     {@code There are no child steps defined}
     */
    public static Localizable _editor_page_common_pipeline_steps_child_require() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.child.require");
    }

    /**
     * Key {@code editor.page.common.add}: {@code Add}.
     * 
     * @return
     *     {@code Add}
     */
    public static String editor_page_common_add() {
        return holder.format("editor.page.common.add");
    }

    /**
     * Key {@code editor.page.common.add}: {@code Add}.
     * 
     * @return
     *     {@code Add}
     */
    public static Localizable _editor_page_common_add() {
        return new Localizable(holder, "editor.page.common.add");
    }

    /**
     * Key {@code editor.page.common.setting}: {@code Settings}.
     * 
     * @return
     *     {@code Settings}
     */
    public static String editor_page_common_setting() {
        return holder.format("editor.page.common.setting");
    }

    /**
     * Key {@code editor.page.common.setting}: {@code Settings}.
     * 
     * @return
     *     {@code Settings}
     */
    public static Localizable _editor_page_common_setting() {
        return new Localizable(holder, "editor.page.common.setting");
    }

    /**
     * Key {@code editor.page.common.cancel}: {@code Cancel}.
     * 
     * @return
     *     {@code Cancel}
     */
    public static String editor_page_common_cancel() {
        return holder.format("editor.page.common.cancel");
    }

    /**
     * Key {@code editor.page.common.cancel}: {@code Cancel}.
     * 
     * @return
     *     {@code Cancel}
     */
    public static Localizable _editor_page_common_cancel() {
        return new Localizable(holder, "editor.page.common.cancel");
    }

    /**
     * Key {@code branchdetail.actionbutton.pipeline.edit}: {@code Edit}.
     * 
     * @return
     *     {@code Edit}
     */
    public static String branchdetail_actionbutton_pipeline_edit() {
        return holder.format("branchdetail.actionbutton.pipeline.edit");
    }

    /**
     * Key {@code branchdetail.actionbutton.pipeline.edit}: {@code Edit}.
     * 
     * @return
     *     {@code Edit}
     */
    public static Localizable _branchdetail_actionbutton_pipeline_edit() {
        return new Localizable(holder, "branchdetail.actionbutton.pipeline.edit");
    }

    /**
     * Key {@code editor.page.common.save}: {@code Save}.
     * 
     * @return
     *     {@code Save}
     */
    public static String editor_page_common_save() {
        return holder.format("editor.page.common.save");
    }

    /**
     * Key {@code editor.page.common.save}: {@code Save}.
     * 
     * @return
     *     {@code Save}
     */
    public static Localizable _editor_page_common_save() {
        return new Localizable(holder, "editor.page.common.save");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.findby.name}: {@code Find
     * steps by name}.
     * 
     * @return
     *     {@code Find steps by name}
     */
    public static String editor_page_common_pipeline_steps_findby_name() {
        return holder.format("editor.page.common.pipeline.steps.findby.name");
    }

    /**
     * Key {@code editor.page.common.pipeline.steps.findby.name}: {@code Find
     * steps by name}.
     * 
     * @return
     *     {@code Find steps by name}
     */
    public static Localizable _editor_page_common_pipeline_steps_findby_name() {
        return new Localizable(holder, "editor.page.common.pipeline.steps.findby.name");
    }

    /**
     * Key {@code editor.page.common.delete}: {@code Delete}.
     * 
     * @return
     *     {@code Delete}
     */
    public static String editor_page_common_delete() {
        return holder.format("editor.page.common.delete");
    }

    /**
     * Key {@code editor.page.common.delete}: {@code Delete}.
     * 
     * @return
     *     {@code Delete}
     */
    public static Localizable _editor_page_common_delete() {
        return new Localizable(holder, "editor.page.common.delete");
    }

    /**
     * Key {@code editor.page.common.pipeline.stages.input}: {@code Name your
     * stage}.
     * 
     * @return
     *     {@code Name your stage}
     */
    public static String editor_page_common_pipeline_stages_input() {
        return holder.format("editor.page.common.pipeline.stages.input");
    }

    /**
     * Key {@code editor.page.common.pipeline.stages.input}: {@code Name your
     * stage}.
     * 
     * @return
     *     {@code Name your stage}
     */
    public static Localizable _editor_page_common_pipeline_stages_input() {
        return new Localizable(holder, "editor.page.common.pipeline.stages.input");
    }

    /**
     * Key {@code editor.jenkins.environment}: {@code Environment}.
     * 
     * @return
     *     {@code Environment}
     */
    public static String editor_jenkins_environment() {
        return holder.format("editor.jenkins.environment");
    }

    /**
     * Key {@code editor.jenkins.environment}: {@code Environment}.
     * 
     * @return
     *     {@code Environment}
     */
    public static Localizable _editor_jenkins_environment() {
        return new Localizable(holder, "editor.jenkins.environment");
    }

    /**
     * Key {@code editor.page.common.pipeline.nestedSequentialStagesError}:
     * {@code The stage named '{0}' contains sequential parallel stages which
     * are not currently supported by the Blue Ocean Pipeline Editor}.
     * 
     * @return
     *     {@code The stage named '{0}' contains sequential parallel stages which
     *     are not currently supported by the Blue Ocean Pipeline Editor}
     */
    public static String editor_page_common_pipeline_nestedSequentialStagesError() {
        return holder.format("editor.page.common.pipeline.nestedSequentialStagesError");
    }

    /**
     * Key {@code editor.page.common.pipeline.nestedSequentialStagesError}:
     * {@code The stage named '{0}' contains sequential parallel stages which
     * are not currently supported by the Blue Ocean Pipeline Editor}.
     * 
     * @return
     *     {@code The stage named '{0}' contains sequential parallel stages which
     *     are not currently supported by the Blue Ocean Pipeline Editor}
     */
    public static Localizable _editor_page_common_pipeline_nestedSequentialStagesError() {
        return new Localizable(holder, "editor.page.common.pipeline.nestedSequentialStagesError");
    }

}
